@@ -403,12 +403,8 @@ clutter_stage_realize (ClutterActor *self)
    */
   if (is_realized)
     {
-    //MAEMO5 PR-1.3 FIX.//
-    // reverting these rows back to git: 568c29ba491e4a6b3bef426be528d7246110011c
     CLUTTER_ACTOR_SET_FLAGS (self, CLUTTER_ACTOR_REALIZED);
     clutter_stage_ensure_current (CLUTTER_STAGE (self));
-    return;
-    //MAEMO5 PR-1.3 FIX.//
 
 
       ClutterBackend *backend = clutter_get_default_backend ();
@@ -419,7 +415,11 @@ clutter_stage_realize (ClutterActor *self)
          Cogl functions. Otherwise it would create the Cogl context
          before we get a chance to check whether the GL version is
          valid */
+#ifndef MAEMO
+//With GLES there are no need to check GL version
+//http://bugzilla.clutter-project.org/show_bug.cgi?id=2426
       _clutter_backend_ensure_context_internal (backend, CLUTTER_STAGE (self));
+#endif
 
       /* Make sure Cogl can support the driver */
       if (!_cogl_check_driver_valid (&error))
